@@ -18,11 +18,10 @@ import os
 import requests
 from urllib.parse import urlparse
 
-# import sys
-# fpath = os.path.join(os.path.dirname(__file__), 'utils')
-# print(fpath)
-# if not np.isin(fpath, sys.path): sys.path.append(fpath)
-# sys.path.append(fpath)
+# import stats as stats
+# from stats import disable_tqdm
+# import interpolate as interpolate
+
 import findpeaks.stats as stats
 from findpeaks.stats import disable_tqdm
 import findpeaks.interpolate as interpolate
@@ -475,7 +474,7 @@ class findpeaks():
             # result = stats.topology(Xproc, limit=self.limit, verbose=self.verbose)
         elif method=='mask':
             # Compute peaks using local maximum filter.
-            result = stats.mask(Xproc, limit=self.limit)
+            result = stats.mask(Xproc, limit=self.limit, verbose=self.verbose)
         else:
             if self.verbose>=2: print('[findpeaks] >WARNING: [method="%s"] is not supported in 2d-array (image) data. <return>' %(self.method))
             return None
